/************************************* THERMISTOR ***************************************/

/**** DEFINES ****/
// the value of the 'other' resistor
#define SERIESRESISTOR 10000 

//Steinhart-Hart equation
// resistance at 25 degrees C for 10.000 resistor
#define THERMISTORNOMINAL 3000
// temp. for nominal resistance (almost always 25 C)
#define TEMPERATURENOMINAL 25
// The beta coefficient of the thermistor (usually 3000-4000)
#define BCOEFFICIENT 3988

// how many samples to take and average
#define NUMSAMPLES 5
//sleep time in sample loop
#define WAITTIME 10


/**** CLASS ****/
class TemperatureThermistor{
  private:
    int pin;
    float toResistance(float inp);
    float toTemp(float resistance);
  
  public:
    TemperatureThermistor(int pin);
    float getTemperature();

};


/**** METHODS ****/
TemperatureThermistor::TemperatureThermistor(int pin){
  this->pin = pin;
}

float TemperatureThermistor::getTemperature(){
  
  //average value
  float average = 0;
  for(int i=0; i < NUMSAMPLES; i++){
    average += analogRead(this->pin);
    delay(WAITTIME);
  }
  
  average /= NUMSAMPLES;
  
  float resistance = this->toResistance(average);
  float temperatureC = this->toTemp(resistance);
  return temperatureC;
}

float TemperatureThermistor::toResistance(float inp){
  float resistance = (1023/inp)-1;
  resistance = SERIESRESISTOR / resistance;
  return resistance;
}

float TemperatureThermistor::toTemp(float resistance){
  //Steinhart-Hart Equation
   float steinhart;
   steinhart = resistance / THERMISTORNOMINAL; // (R/Ro)
   steinhart = log(steinhart); // ln(R/Ro)
   steinhart /= BCOEFFICIENT; // 1/B * ln(R/Ro)
   steinhart += 1.0 / (TEMPERATURENOMINAL + 273.15); // + (1/To)
   steinhart = 1.0 / steinhart; // Invert
   steinhart -= 273.15; 
   return steinhart;

}


